@@ -7,7 +7,7 @@ use CairoX::Sweet::Standard;
 
 class CairoX::Sweet using Moose {
 
-    our $VERSION = '0.0107'; # VERSION
+    our $VERSION = '0.0108'; # VERSION
     # ABSTRACT: Wraps Cairo for easier drawing
 
     use Cairo;
@@ -129,9 +129,24 @@ __END__
 
 CairoX::Sweet - Wraps Cairo for easier drawing
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-CairoX-Sweet"><img src="https://api.travis-ci.org/Csson/p5-CairoX-Sweet.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-CairoX-Sweet.svg?branch=master)](https://travis-ci.org/Csson/p5-CairoX-Sweet)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.0107, released 2015-03-19.
+Version 0.0108, released 2015-03-21.
 
 =head1 SYNOPSIS
 
